@@ -63,7 +63,7 @@ class API(_API):
                             security_groups=security_groups, quiet=quiet)
         self.default_stepfunction_name = default_stepfunction_name
 
-    def deploy_zebra(self, suffix=None, usergroup='', subnets=None, security_groups=None, env=None):
+    def deploy_zebra(self, suffix=None, usergroup='', subnets=None, security_groups=None, env=None, deploy_costupdater=False):
         if env:
             usergroup = env + '_' + usergroup if usergroup else env
         else:
@@ -73,5 +73,5 @@ class API(_API):
                 env = PROD_ENV
         self.deploy_tibanna(suffix=suffix, usergroup=usergroup, setup=True, default_usergroup_tag='',
                             do_not_delete_public_access_block=True, no_randomize=True,
-                            buckets=','.join(IAM_BUCKETS(env)), deploy_costupdater=True,
+                            buckets=','.join(IAM_BUCKETS(env)), deploy_costupdater=deploy_costupdater,
                             subnets=subnets, security_groups=security_groups)
